/***************************************************************************
 *   Copyright (C) 2004 by Toplica Tanaskovic                              *
 *   toptan@kde.org.yu                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "edacomplinedata.h"
#include <qwmatrix.h>

EDACompLineData::EDACompLineData(const QPoint & pos, const QPoint & vector, const QColor & color, QObject *parent, const char *name)
 : EDACompPolylineBaseData(pos, color, parent, name), m_vector(vector)
{
}

EDACompLineData::EDACompLineData(const QPoint & pos, double size, double angle, const QColor & color, QObject *parent, const char *name)
 : EDACompPolylineBaseData(pos, color, parent, name)
{
    m_vector.setX(int(round(size*cos(M_PI/180*angle))));
    m_vector.setY(int(round(size*sin(M_PI/180*angle))));
    m_angle = angle;
}

EDACompLineData::~EDACompLineData()
{
}




/*!
    \fn EDACompLineData::getVector() const
 */
QPoint EDACompLineData::getVector() const
{
    return m_vector;
}


/*!
    \fn EDACompLineData::setVector(const QPoint & vector)
 */
void EDACompLineData::setVector(const QPoint & vector)
{
    m_vector = vector;
    emit signalUpdateData();
}


/*!
    \fn EDACompLineData::getSize() const
 */
double EDACompLineData::getSize() const
{
    return sqrt(m_vector.x()*m_vector.x()+m_vector.y()*m_vector.y());
}


/*!
    \fn EDACompLineData::setSize(double size)
 */
void EDACompLineData::setSize(double size)
{
    m_vector.setX(int(round(size*cos(M_PI/180*m_angle))));
    m_vector.setY(int(round(size*sin(M_PI/180*m_angle))));
    emit signalUpdateData();
}


/*!
    \fn EDACompLineData::recalc()
 */
void EDACompLineData::recalc()
{
    QWMatrix m;
    QPoint temp;
    m.rotate(m_angle);
    temp = m.map(m_vector);
    m_vector = temp;
}
