/***************************************************************************
 *   Copyright (C) 2004 by Toplica Tanaskovic                              *
 *   toptan@kde.org.yu                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "edacompprimitivedatabase.h"

#include <qpoint.h>
#include <qcolor.h>
#include <qwmatrix.h>

EDACompPrimitiveDataBase::EDACompPrimitiveDataBase(const QPoint & pos, const QColor & color, QObject *parent, const char *name)
 : QObject(parent, name), m_position(pos), m_color(color), m_angle(0)
{
}


EDACompPrimitiveDataBase::~EDACompPrimitiveDataBase()
{
}


/*!
    \fn EDACompPrimitiveDataBase::setPosition(const QPoint & pos)
 */
void EDACompPrimitiveDataBase::setPosition(const QPoint & pos)
{
    m_position = pos;
    emit signalUpdateData();
}


/*!
    \fn EDACompPrimitiveDataBase::getPosition() const
 */
QPoint EDACompPrimitiveDataBase::getPosition() const
{
    return m_position;
}


/*!
    \fn EDACompPrimitiveDataBase::move(const QPoint & vector)
 */
void EDACompPrimitiveDataBase::move(const QPoint & vector)
{
    m_position += vector;
    emit signalUpdateData();
}


/*!
    \fn EDACompPrimitiveDataBase::getColor() const
 */
QColor EDACompPrimitiveDataBase::getColor() const
{
    return m_color;
}


/*!
    \fn EDACompPrimitiveDataBase::setColor(const QColor & color)
 */
void EDACompPrimitiveDataBase::setColor(const QColor & color)
{
    m_color = color;
    emit signalUpdateData();
}


/*!
    \fn EDACompPrimitiveDataBase::getAngle() const
 */
double EDACompPrimitiveDataBase::getAngle() const
{
    return m_angle;
}


/*!
    \fn EDACompPrimitiveDataBase::setAngle(double angle)
 */
void EDACompPrimitiveDataBase::setAngle(double angle)
{
    m_angle = angle;
    recalc();
    emit signalUpdateData();
}


/*!
    \fn EDACompPrimitiveDataBase::rotate(double delta)
 */
void EDACompPrimitiveDataBase::rotate(double delta)
{
    m_angle += delta;
    recalc();
    emit signalUpdateData();
}
