/***************************************************************************
 *   Copyright (C) 2004 by Toplica Tanaskovic                              *
 *   toptan@kde.org.yu                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "edacomprectdata.h"
#include <qwmatrix.h>

EDACompRectData::EDACompRectData(const QPoint & pos, const QSize & size, const QColor & color, QObject *parent, const char *name)
 : EDACompPolylineBaseData(pos, color, parent, name), m_size(size), m_brush(QBrush()), m_points(3)
{
    m_points.setPoint(0, size.width(), 0);
    m_points.setPoint(1, size.width(), -size.height());
    m_points.setPoint(2, 0, -size.height());
}


EDACompRectData::~EDACompRectData()
{
}




/*!
    \fn EDACompRectData::getSize() const
 */
QSize EDACompRectData::getSize() const
{
    return m_size;
}


/*!
    \fn EDACompRectData::getBrush() const
 */
QBrush EDACompRectData::getBrush() const
{
    return m_brush;
}


/*!
    \fn EDACompRectData::setBrush(const QBrush & brush)
 */
void EDACompRectData::setBrush(const QBrush & brush)
{
    m_brush = brush;
    emit signalUpdateData();
}


/*!
    \fn EDACompRectData::setSize(const QSize & size)
 */
void EDACompRectData::setSize(const QSize & size)
{
    m_size = size;
    emit signalUpdateData();
}


/*!
    \fn EDACompRectData::recalc()
 */
void EDACompRectData::recalc()
{
    QWMatrix m;
    QPoint temp;
    m.rotate(m_angle);
    temp = m.map(m_points.point(0));
    m_points.setPoint(0, temp);
    temp = m.map(m_points.point(1));
    m_points.setPoint(1, temp);
    temp = m.map(m_points.point(2));
    m_points.setPoint(2, temp);
}
